SavedObjectsExtractor

Struct SavedObjectsExtractor 

pub struct SavedObjectsExtractor { /* private fields */ }
Extractor for Kibana saved objects

Exports saved objects from Kibana using the manifest as the export specification. The manifest defines which objects to export and is sent as the POST body.

Example

use kibana_sync::kibana::saved_objects::{SavedObjectsExtractor, SavedObjectsManifest, SavedObject};
use kibana_sync::client::{Auth, KibanaClient};
use kibana_sync::etl::Extractor;
use url::Url;

let url = Url::parse("http://localhost:5601")?;
let client = KibanaClient::new(url, Auth::None)?;
let space_client = client.space("default")?;
let mut manifest = SavedObjectsManifest::new();
manifest.add_object(SavedObject::new("dashboard", "my-dashboard-id"));

let extractor = SavedObjectsExtractor::new(space_client, manifest);
let objects = extractor.extract().await?;

Implementations

Source

impl SavedObjectsExtractor

pub fn new(client: KibanaClient, manifest: SavedObjectsManifest) -> Self

Create a new saved objects extractor

Arguments
  • client - Space-scoped Kibana client
  • manifest - Manifest defining which objects to export